@@ -15,18 +15,18 @@ class DingDingPlugin(NotificationPlugin):
     """
     Sentry plugin to send error counts to DingDing.
     """
-    author = 'season'
+    author = 'dreamerldq'
     author_url = 'https://github.com/cench/sentry-10-dingding'
     version = sentry_dingding.VERSION
-    description = 'Send error counts to DingDing.'
+    description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/cench/sentry-10-dingding'),
         ('Bug Tracker', 'https://github.com/cench/sentry-10-dingding/issues'),
         ('README', 'https://github.com/cench/sentry-10-dingding/blob/master/README.md'),
     ]
 
-    slug = 'DingDing'
-    title = 'DingDing'
+    slug = 'WbDingDing'
+    title = 'WbDingDing'
     conf_key = slug
     conf_title = title
     project_conf_form = DingDingOptionsForm
@@ -58,9 +58,9 @@ class DingDingPlugin(NotificationPlugin):
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": u"#### {title} \n\n > {title} \n\n > {event} \n\n [详细信息]({url})".format(
+                "text": u"#### {title} \n\n > {title} \n\n > {path} \n\n [详细信息]({url})".format(
                     title=title,
-                    event=json.dumps(event),
+                    path=event.tags.url,
                     message=event.title or event.message,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 )
